#
# Copyright (C) 2017 VEXXHOST, Inc.
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.
#
#  Author: Mohammed Naser <mnaser@vexxhost.com>
#
require 'spec_helper'

describe 'ceph::profile::mgr' do

  shared_examples 'ceph profile mgr' do
    it { should contain_ceph__mgr('first').with(
      :authentication_type => 'cephx',
      :key                 => 'AQASGFDFUHBHDG9SDdsyffV1xgsn1pgr3GcKPg==',
      :inject_key          => true)
    }
  end

  on_supported_os.each do |os, facts|
    context "on #{os}" do
      let(:facts) do
        facts.merge({:hostname => 'first'})
      end

      it_behaves_like 'ceph profile mgr'
    end
  end
end
